yakumo.nova.v2.flavor.Manager

Package yakumo :: Package nova :: Package v2 :: Module flavor :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for flavors in Compute API v2

Nested Classes | [hide private]
| resource_class Resource class for flavors in Compute API v2

Instance Methods | [hide private]
yakumo.nova.v2.flavor.Resource |
create(self, id=`'``__UNDEF__``'`, name=`'``__UNDEF__``'`, ram=`'``__UNDEF__``'`, vcpus=`'``__UNDEF__``'`, disk=`'``__UNDEF__``'`, ephemeral=`'``__UNDEF__``'`, swap=`'``__UNDEF__``'`, rxtx_factor=`'``__UNDEF__``'`, is_public=`'``__UNDEF__``'`) Register a flavor | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``compute``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _hidden_methods = ``[``'``update``'``]``
| _json_resource_key = ``'``flavor``'``
| _json_resources_key = ``'``flavors``'``
| _url_resource_path = ``'``/flavors``'``
| _url_resource_list_path = ``'``/flavors/detail``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_id_attr`, `_update_method`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, id=`'``__UNDEF__``'`, name=`'``__UNDEF__``'`, ram=`'``__UNDEF__``'`, vcpus=`'``__UNDEF__``'`, disk=`'``__UNDEF__``'`, ephemeral=`'``__UNDEF__``'`, swap=`'``__UNDEF__``'`, rxtx_factor=`'``__UNDEF__``'`, is_public=`'``__UNDEF__``'`) | source code
Register a flavor Parameters: `id` (int) - ID of the new flavor (int) `name` (str) - name of the new flavor (str) `vcpus` (int) - number of virtual CPU(s) (int) `ram` (int) - size of RAM in MB (int) `disk` (int) - size of ephemeral disk for image in GB (int) `ephemeral` (int) - size of extra ephemeral disk in GB (int) `swap` (int) - size of swap ephemeral disk in GB (int) `rxtx_factor` (float) - rate of bandwidth cap (float) `is_public` (bool) - the new flavor is public or not (bool) Returns: yakumo.nova.v2.flavor.Resource Registered flavor Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('ram', 'ra
      m', mapper.Noop), ('vcpus', 'vcpus', mapper.Noop), ('disk', 'disk', ma
      pper.Noop), ('ephemeral', 'OS-FLV-EXT-DATA:ephemeral', mapper.Noop), (
      'swap', 'swap', mapper.Noop), ('rxtx_factor', 'rxtx_factor', mapper.No
      op), ('is_public', 'os-flavor-access:is_public', mapper.Noop),]